"use client";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";
import { Label } from "@/components/ui/label";
import { Input } from "@/components/ui/input";
import { Button } from "@/components/ui/button";
import { cn } from "@/lib/utils";
import toast, { Toaster } from "react-hot-toast";
import { useTranslations } from "next-intl";
import { postWithToken } from "@/Helper/common";
import { useRouter } from "next/navigation";
import React, { useState, useEffect } from "react";

const SetMpin = () => {
  const lang = useTranslations("SetMPin");
  const schema = z.object({
    MPin: z.string().min(3, { message: lang("Enter_MPin") }),
    Password: z.string().min(3, { message: lang("Enter_Password") }),

    confirmPassword: z
      .string()
      .min(3, { message: lang("Enter_Confirm_Password") }),
  });
  const route = useRouter();
  const [loading, setLoading] = useState(false);

  const {
    register,
    handleSubmit,
    formState: { errors },
  } = useForm({
    resolver: zodResolver(schema),
  });

  async function onSubmit(data) {
    toast.dismiss();
    setLoading(true);
    const apiData = JSON.stringify({
      mpin: data.MPin,
      password: data.Password,
      confirm_password: data.confirmPassword,
    });
    if (!data.MPin.trim()) {
      toast.error("MPin is required", {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
    } else {
      try {


        const data = await postWithToken("pin-set", apiData);

        if (data.error == false) {
          toast.success(data.message, {
            position: "bottom-center",
            style: { borderRadius: "10px", background: "#333", color: "#fff" },
          });

          route.push("/admin/dashboard");
        } else {
          toast.error(data.message, {
            position: "bottom-center",
            style: { borderRadius: "10px", background: "#333", color: "#fff" },
          });
        }
      } catch (errorData) {
        toast.error(errorData.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
      } finally {
        setLoading(false);
      }
    }
  }
  return (
    <form onSubmit={handleSubmit(onSubmit)}>
      <div className="grid grid-cols-1 lg:grid-cols-2 gap-4">
        <div className="flex flex-col gap-2">
          <Label htmlFor="MPin">{lang("Enter_MPin")} (Use only 4 Digit Mpin)</Label>
          <Input
            type="text"
            {...register("MPin", {
              setValueAs: (value) => value.split(" ").join("")
            })}
            placeholder={lang("Enter_MPin")}
            maxLength={4}
            minLength={4}
            className={cn("", {
              "border-destructive focus:border-destructive": errors.author,
            })}
            pattern="\d*" // Ensures only digits are valid
            onInput={(e) => e.target.value = e.target.value.replace(/\D/g, '')}
          />
          {errors.MPin && (
            <p
              className={cn("text-xs", {
                "text-destructive": errors.MPin,
              })}
            >
              {errors.MPin.message}
            </p>
          )}
        </div>

        <div className="flex flex-col gap-2">
          <Label htmlFor="Password">{lang("Enter_Password")} (Enter Your Password like demo@1234)</Label>
          <Input
            type="password"
            {...register("Password", {
              setValueAs: (value) => value.split(" ").join("")
            })}
            placeholder={lang("Enter_Password")}
            className={cn("", {
              "border-destructive focus:border-destructive": errors.author,
            })}
            onInput={(e) => {
              e.target.value = e.target.value.split(" ").join("");
            }}

          />
          {errors.Password && (
            <p
              className={cn("text-xs", {
                "text-destructive": errors.Password,
              })}
            >
              {errors.Password.message}
            </p>
          )}
        </div>

        <div className="flex flex-col gap-2">
          <Label htmlFor="Confirm Password">
            {lang("Enter_Confirm_Password")}
          </Label>
          <Input
            type="password"
            {...register("confirmPassword", {
              setValueAs: (value) => value.split(" ").join("")
            })}
            placeholder={lang("Enter_Confirm_Password")}
            className={cn("", {
              "border-destructive focus:border-destructive": errors.author,
            })}
            onInput={(e) => {
              e.target.value = e.target.value.split(" ").join("");
            }}
          />
          {errors.confirmPassword && (
            <p
              className={cn("text-xs", {
                "text-destructive": errors.confirmPassword,
              })}
            >
              {errors.confirmPassword.message}
            </p>
          )}
        </div>
      </div>

      <div className="mt-10 flex justify-center ">
        {/* <div>
       <Button onClick={handleReset} className=" mx-auto" type="submit"> {lang("Submit")}</Button>
       </div> */}
        <Button className="" type="submit" disabled={loading}>
          {lang("Submit")}
          {loading ? (
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="2em"
              height="2em"
              viewBox="0 0 24 24"
            >
              <g
                fill="none"
                stroke="currentColor"
                stroke-linecap="round"
                stroke-width="2"
              >
                <path
                  stroke-dasharray="60"
                  stroke-dashoffset="60"
                  stroke-opacity="0.3"
                  d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                >
                  <animate
                    fill="freeze"
                    attributeName="stroke-dashoffset"
                    dur="1.3s"
                    values="60;0"
                  />
                </path>
                <path
                  stroke-dasharray="15"
                  stroke-dashoffset="15"
                  d="M12 3C16.9706 3 21 7.02944 21 12"
                >
                  <animate
                    fill="freeze"
                    attributeName="stroke-dashoffset"
                    dur="0.3s"
                    values="15;0"
                  />
                  <animateTransform
                    attributeName="transform"
                    dur="1.5s"
                    repeatCount="indefinite"
                    type="rotate"
                    values="0 12 12;360 12 12"
                  />
                </path>
              </g>
            </svg>
          ) : null}
        </Button>
      </div>
    </form>
  );
};

export default SetMpin;
